@@ -4,7 +4,6 @@ import sys
 
 from google.cloud import storage
 import tensorflow as tf
-import tensorflow_hub as hub
 
 
 def load_model_clear(path, include_top=True):
@@ -19,7 +18,7 @@ def load_model_clear(path, include_top=True):
         tf.keras model: loaded model
     """
     tf.keras.backend.clear_session()
-    model = tf.keras.models.load_model(path, compile=include_top, custom_objects={"KerasLayer": hub.KerasLayer})
+    model = tf.keras.models.load_model(path, compile=include_top)
     print('Model loaded !')
     if not include_top:
         model = tf.keras.Model(inputs=model.input, outputs=model.layers[-2].output)
